Certificats | OiRA
Description: En funció de l’enfocament que hagi adoptat el soci o desenvolupador nacional de l’eina OiRA, és possible obtenir un certificat de l’avaluació de riscos. Si voleu rebre informació detallada sobre els avantatges d’aquests certificats, cal que us poseu en contacte amb el soci nacional OIRA.

Temes

# Certificats

En funció de l’enfocament que hagi adoptat el soci o desenvolupador nacional de l’eina OiRA, és possible obtenir un certificat de l’avaluació de riscos. Si voleu rebre informació detallada sobre els avantatges d’aquests certificats, cal que us poseu en contacte amb el soci nacional OIRA.

Com s’obté un certificat?

## Fer una avaluació de riscos completa

A mesura que feu l’avaluació de riscos, OiRA registrarà els vostres avanços. Un cop hàgiu avaluat un percentatge de riscos, l’eina us informarà de la possibilitat d’obtenir un certificat quan hàgiu fet l’avaluació de riscos completa. Cada soci o desenvolupador nacional de l’eina OiRA estableix el llindar a partir del qual l’avaluació de riscos es considera completa. El certificat està disponible mitjançant el botó «Grau d’emplenament» al menú de l’esquerra.

Pantalla amb l’avís sobre el certificat

## Consulteu i publiqueu el certificat

Quan cliqueu al botó «Vegeu el certificat», us demanarà que introduïu el nom de la vostra empresa, que ha de constar en el certificat. En funció de la configuració nacional, és possible que us demani que introduïu més dades per assegurar-se que el certificat inclou tota la informació que cal facilitar.

Si marqueu la casella «Publiqueu», se us mostrarà un enllaç únic (URL) al vostre certificat. Copieu aquest enllaç i compartiu-lo amb qui us interessi, com a prova que heu fet l’avaluació de riscos.

Publicar el certificat

Nota: Només es faran públiques les dades que surten en aquesta pàgina. Aquest enllaç no està disponible mitjançant el menú de cap lloc web; és específicament vostre. No obstant això, teòricament qualsevol persona que navegui per internet podria veure el certificat que heu pujat.

El certificat només indica que heu respost a un determinat percentatge de riscos a l’eina d’avaluació de riscos, però no facilita cap més informació. Ningú més podrà veure les respostes específiques a l’avaluació de riscos que es donen quan es completa l’eina OIRA.

Scroll to top Load toolbar…
Back

## 5-certificates.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More